Coverage for src\pqlattice\lattice\_hkz.py: 100%

1 from ..typing import SquareMatrix, validate_aliases

2 from ._bkz import bkz

3 from ._lattice import rank

4

5

6@validate_aliases

7 def hkz(lattice_basis: SquareMatrix) -> SquareMatrix:

8 """_summary_

9

10 Parameters

11 ----------

12 lattice_basis : SquareMatrix

13 _description_

14

15 Returns

16 -------

17 SquareMatrix

18 _description_

19 """

20 return bkz(lattice_basis, rank(lattice_basis))